# handsome

> a shiny suit for wrapping fine-looking machine learning models

[![codecov](https://codecov.io/gh/withtwoemms/handsome/graph/badge.svg?token=7SAGH7XO28)](https://codecov.io/gh/withtwoemms/handsome)
